
From: Denis Vlasenko <vda@ilport.com.ua>

cs89x0 talks a lot at boot.  Seems like debug leftover.  This patch
downgrades printks to KERN_DEBUG.  While we're at it, make these messages a
bit less obscure.

Cc: Jeff Garzik <jgarzik@pobox.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/net/cs89x0.c |   12 ++++++++----
 drivers/net/cs89x0.h |    1 +
 2 files changed, 9 insertions(+), 4 deletions(-)

diff -puN drivers/net/cs89x0.c~silence-cs89x0 drivers/net/cs89x0.c
--- 25/drivers/net/cs89x0.c~silence-cs89x0	2005-06-25 14:19:56.000000000 -0700
+++ 25-akpm/drivers/net/cs89x0.c	2005-06-25 14:19:56.000000000 -0700
@@ -423,6 +423,7 @@ cs89x0_probe1(struct net_device *dev, in
 	struct net_local *lp = netdev_priv(dev);
 	static unsigned version_printed;
 	int i;
+	int tmp;
 	unsigned rev_type = 0;
 	int eeprom_buff[CHKSUM_LEN];
 	int retval;
@@ -498,14 +499,17 @@ cs89x0_probe1(struct net_device *dev, in
 				goto out2;
 			}
 	}
-printk("PP_addr=0x%x\n", inw(ioaddr + ADD_PORT));
+	printk(KERN_DEBUG "PP_addr at %x: 0x%x\n",
+			ioaddr + ADD_PORT, inw(ioaddr + ADD_PORT));
 
 	ioaddr &= ~3;
 	outw(PP_ChipID, ioaddr + ADD_PORT);
 
-	if (inw(ioaddr + DATA_PORT) != CHIP_EISA_ID_SIG) {
-		printk(KERN_ERR "%s: incorrect signature 0x%x\n",
-			dev->name, inw(ioaddr + DATA_PORT));
+	tmp = inw(ioaddr + DATA_PORT);
+	if (tmp != CHIP_EISA_ID_SIG) {
+		printk(KERN_DEBUG "%s: incorrect signature at %x: 0x%x!="
+			CHIP_EISA_ID_SIG_STR "\n",
+			dev->name, ioaddr + DATA_PORT, tmp);
   		retval = -ENODEV;
   		goto out2;
 	}
diff -puN drivers/net/cs89x0.h~silence-cs89x0 drivers/net/cs89x0.h
--- 25/drivers/net/cs89x0.h~silence-cs89x0	2005-06-25 14:19:56.000000000 -0700
+++ 25-akpm/drivers/net/cs89x0.h	2005-06-25 14:19:56.000000000 -0700
@@ -93,6 +93,7 @@
 #endif
 
 #define CHIP_EISA_ID_SIG 0x630E   /*  Product ID Code for Crystal Chip (CS8900 spec 4.3) */
+#define CHIP_EISA_ID_SIG_STR "0x630E"
 
 #ifdef IBMEIPKT
 #define EISA_ID_SIG 0x4D24	/*  IBM */
_
